@@ -8,11 +8,12 @@
     :copyright: Conceptual Vision Consulting LLC 2018-2019, see AUTHORS for more details.
     :license: MIT, see LICENSE for more details.
 """
+from typing import Any, List
 
 
-class RecursiveMapConverter():
+class RecursiveMapConverter:
     """
-    Converts arbitrary values into map objects using extended conversion rules.
+    Converts arbitrary values into map objects using extended conversion __rules.
     This class is similar to :class:`MapConverter <pip_services3_commons.convert.MapConverter.MapConverter>`, but is recursively converts all values stored in objects and arrays.
 
     Example:
@@ -25,27 +26,27 @@ class RecursiveMapConverter():
     """
 
     @staticmethod
-    def _value_to_map(value, classkey=None):
+    def __value_to_map(value: Any, classkey=None) -> Any:
 
         if isinstance(value, dict):
-            return RecursiveMapConverter._map_to_map(value, classkey)
+            return RecursiveMapConverter.__map_to_map(value, classkey)
 
         elif isinstance(value, list):
-            return RecursiveMapConverter._array_to_map(value)
-        
+            return RecursiveMapConverter.__array_to_map(value)
+
         elif hasattr(value, "_ast"):
-            return RecursiveMapConverter._value_to_map(value._ast())
+            return RecursiveMapConverter.__value_to_map(value._ast())
 
         elif hasattr(value, "__iter__") and type(value) != str:
-            return [RecursiveMapConverter._value_to_map(v, classkey) for v in value]
+            return [RecursiveMapConverter.__value_to_map(v, classkey) for v in value]
 
         elif hasattr(value, "__dict__"):
-            data = {} 
+            data = {}
 
             for k in dir(value):
                 v = getattr(value, k)
                 if not callable(v) and not k.startswith('_'):
-                    data[k] = RecursiveMapConverter._value_to_map(v, classkey)
+                    data[k] = RecursiveMapConverter.__value_to_map(v, classkey)
 
             if classkey is not None and hasattr(value, "__class__"):
                 data[classkey] = value.__class__.__name__
@@ -54,42 +55,42 @@ class RecursiveMapConverter():
             return value
 
     @staticmethod
-    def _array_to_map(value):
+    def __array_to_map(value: List[Any]) -> Any:
         result = {}
         try:
             for i in range(len(value)):
-                result[i] = RecursiveMapConverter._value_to_map(value[i])
+                result[i] = RecursiveMapConverter.__value_to_map(value[i])
             return result
         except TypeError:
             return value
 
     @staticmethod
-    def _map_to_map(value, classkey = None):
+    def __map_to_map(value: Any, classkey=None) -> Any:
         data = {}
         for (k, v) in value.items():
-            data[k] = RecursiveMapConverter._value_to_map(v, classkey)
+            data[k] = RecursiveMapConverter.__value_to_map(v, classkey)
         return data
-    
-    @staticmethod
-    def to_nullable_map(value):
-        """
-        Converts value into map object or returns null when conversion is not possible.
 
-        :param value: the value to convert.
+    @staticmethod
+    def to_nullable_map(value: Any) -> Any:
+        """
+        Converts args into map object or returns null when conversion is not possible.
+
+        :param value: the args to convert.
 
         :return: map object or null when conversion is not supported.
         """
         if value is None:
             return None
 
-        return RecursiveMapConverter._value_to_map(value)
+        return RecursiveMapConverter.__value_to_map(value)
 
     @staticmethod
-    def to_map(value):
+    def to_map(value: Any) -> Any:
         """
-        Converts value into map object or returns empty map when conversion is not possible
+        Converts args into map object or returns empty map when conversion is not possible
 
-        :param value: the value to convert.
+        :param value: the args to convert.
 
         :return: map object or empty map when conversion is not supported.
         """
@@ -97,13 +98,13 @@ class RecursiveMapConverter():
         return result if result is not None else {}
 
     @staticmethod
-    def to_map_with_default(value, default_value):
+    def to_map_with_default(value: Any, default_value: Any) -> Any:
         """
-        Converts value into map object or returns default when conversion is not possible
+        Converts args into map object or returns default when conversion is not possible
 
-        :param value: the value to convert.
+        :param value: the args to convert.
 
-        :param default_value: the default value.
+        :param default_value: the default args.
 
         :return: map object or emptu map when conversion is not supported.
         """
