@@ -8,8 +8,11 @@
     :copyright: Conceptual Vision Consulting LLC 2018-2019, see AUTHORS for more details.
     :license: MIT, see LICENSE for more details.
 """
+from abc import ABC
+from datetime import datetime
 
-class IChangeable:
+
+class IChangeable(ABC):
     """
     Interface for data objects that contain their latest change time.
 
@@ -18,9 +21,10 @@ class IChangeable:
     .. code-block:: python
 
         class MyData(IStringIdentifiable, IChangeable):
-            id = None
-            change_time = None
+            id: str = '1234567'
+            field1: str = 'field1'
+            field2: int = 123
+            change_time: datetime = datetime.now()
 
     """
-    # change_time = None
-    pass
+    change_time: datetime = None
