@@ -17,7 +17,7 @@ __all__ = [
     'ValueComparisonRule', 'PropertiesComparisonRule',
     'OnlyOneExistRule', 'ExcludedRule', 'IncludedRule',
     'Schema', 'PropertySchema', 'ObjectSchema', 'ArraySchema', 'MapSchema',
-    'FilterParamsSchema', 'PagingParamsSchema'
+    'FilterParamsSchema', 'PagingParamsSchema', 'ProjectionParamsSchema'
 ]
 
 from .ValidationResultType import ValidationResultType
@@ -30,8 +30,9 @@ from .NotRule import NotRule
 from .ObjectComparator import ObjectComparator
 from .ValueComparisonRule import ValueComparisonRule
 from .PropertiesComparisonRule import PropertiesComparisonRule
+from .ProjectionParamsSchema import ProjectionParamsSchema
 from .OnlyOneExistRule import OnlyOneExistRule
-from .AtLeastOneExistRule import AtLeastOneExistRule
+from .AtLeastOneExistsRule import AtLeastOneExistsRule
 from .ExcludedRule import ExcludedRule
 from .IncludedRule import IncludedRule
 from .Schema import Schema
